This is normally an internal function, but it can be overloaded to extend simr to other packages.
Usage
doSim(object, ...)
Arguments
object
an object to simulare from, usually a fitted model.
...
additional options.
Value
a vector containing simulated response values (or, for models with a multivariate response such as
binomial gl(m)m's, a matrix of simulated response values). Suitable as input for doFit.